@@ -17,13 +17,19 @@ my $params = {
 
 my $des = Devel::Examine::Subs->new($params);
 
-timethese(10, {
+timethese(100, {
             'enabled' => 'cache_enabled',
             'disabled' => 'cache_disabled',
         });
+
 sub cache_disabled {
     $des->all({cache => 0,}) for (1..10);
 }
 sub cache_enabled {
     $des->all({cache => 1,}) for (1..10);
 }
+
+__END__
+Benchmark: timing 100 iterations of disabled, enabled...
+  disabled: 72 wallclock secs (66.33 usr +  5.18 sys = 71.51 CPU) @  1.40/s (n=100)
+   enabled:  0 wallclock secs ( 0.06 usr +  0.01 sys =  0.07 CPU) @ 1428.57/s (n=100)
